#!/usr/bin/env groovy

import com.urbancode.codestation2.client.*
import com.urbancode.codestation2.client.base.*
import com.urbancode.codestation2.client.util.*
import org.apache.log4j.BasicConfigurator
import org.apache.log4j.Level
import org.apache.log4j.Logger

BasicConfigurator.resetConfiguration()
BasicConfigurator.configure()
Logger.getRootLogger().setLevel(Level.ERROR)

final def workDir = new File('.').canonicalFile
final def inputPropsFile = new File(args[0])
final def outputPropsFile = new File(args[1])

final def props = new Properties()
try {
    props.load(new FileInputStream(inputPropsFile))
}
catch (IOException e) {
    throw new RuntimeException(e)
}

final def anthillUrl      = props['anthillUrl']
final def anthillUser     = props['anthillUser']
final def anthillPassword = props['anthillPassword']
final def projectName     = props['projectName']
final def workflowName    = props['workflowName']
final def buildLifeId     = props['buildLifeId']
final def buildLifeStamp  = props['buildLifeStamp']
final def buildLifeStatus = props['buildLifeStatus']
final def artifactSetName = props['artifactSetName']

final def credentials = new Credentials(anthillUser, anthillPassword)
final def clientLogger = Logger.getLogger("Codestation Client")
final def clientLogBridge = new Log4jBridge(clientLogger)

clientLogger.setLevel(Level.INFO)

def clientBuilder = new CodestationFacadeBuilder()
clientBuilder.setServer(anthillUrl)
clientBuilder.setNoCheckCertificate(true)
clientBuilder.setCredentials(credentials)
clientBuilder.setLog(clientLogBridge)
clientBuilder.setForce(true)
clientBuilder.setVerbose(true)
clientBuilder.setSuppressBoms(true)
clientBuilder.setIncludeDirsAndSymlinks(false)
clientBuilder.setIncludePermissions(false)
clientBuilder.setWorkingDir(workDir)

def client = clientBuilder.build()

if (buildLifeId) {
    client.resolveArtifacts(projectName, workflowName, Long.valueOf(buildLifeId), artifactSetName);
}
else {
    client.resolveArtifacts(projectName, workflowName, buildLifeStamp, buildLifeStatus, artifactSetName);
}
