#!/usr/bin/env groovy

import com.urbancode.air.integration.*
import org.apache.log4j.BasicConfigurator
import org.apache.log4j.Level
import org.apache.log4j.Logger
import com.urbancode.air.XTrustProvider;
import com.urbancode.anthill3.integration.*;


XTrustProvider.install();

BasicConfigurator.resetConfiguration()
BasicConfigurator.configure()
Logger.getRootLogger().setLevel(Level.ERROR)

final def workDir = new File('.').canonicalFile
final def inputPropsFile = new File(args[0])
final def outputPropsFile = new File(args[1])

final def props = new Properties()
try {
    props.load(new FileInputStream(inputPropsFile))
}
catch (IOException e) {
    throw new RuntimeException(e)
}

final def anthillUrl      = props['anthillUrl']
final def anthillUser     = props['anthillUser']
final def anthillPassword = props['anthillPassword']
final def projectName     = props['projectName']
final def workflowName    = props['workflowName']
final def envName         = props['envName']
final def buildLifeId     = props['buildLifeId']
final def properties      = props['properties']

// parse the additional fields into a Properties object
def workflowProps = new Properties()
if (properties) {
    try {
        workflowProps.load(new ByteArrayInputStream(properties.getBytes()))
    }
    catch (Exception e) {
        throw new Exception("Workflow properties formatted incorrectly: " + e.getMessage())
    }
}
def propertyFacadeArray = new PropertyFacade[workflowProps.size()]
def propertyIndex = 0
workflowProps.each() { workflowProp ->
    //println "Adding property '${workflowProp.key}' with value '${workflowProp.value}'"
    propertyFacadeArray[propertyIndex++] = new PropertyFacade(workflowProp.key, workflowProp.value)
}

println "Connecting to ${anthillUrl}"

def locator = new DashboardServiceLocator()

def dashboard = locator.getDashboard(new URL("${anthillUrl}/services/Dashboard"))

def requestFacade = null
if (buildLifeId) {
    println "Running secondary workflow '${workflowName}' on build life ${buildLifeId} in environment '${envName}'."
    requestFacade = dashboard.runWorkflowWithPropertiesByName(
        anthillUser, anthillPassword, buildLifeId, workflowName, envName, propertyFacadeArray)
}
else {
    println "Running build workflow '${workflowName}' for project '${projectName}'."
    requestFacade = dashboard.buildProjectWithPropertiesByName(
        anthillUser, anthillPassword, projectName, workflowName, true, propertyFacadeArray)
}

println "Created request ${requestFacade.id}"
